@@ -159,7 +159,7 @@ nzb_backup_dir = OptionDir('misc', 'nzb_backup_dir', DEF_NZBBACK_DIR)
 cache_dir = OptionDir('misc', 'cache_dir', 'cache', create=False, validation=validate_safedir)
 admin_dir = OptionDir('misc', 'admin_dir', DEF_ADMIN_DIR, validation=validate_safedir)
 #log_dir = OptionDir('misc', 'log_dir', 'logs')
-dirscan_dir = OptionDir('misc', 'dirscan_dir', create=True)
+dirscan_dir = OptionDir('misc', 'dirscan_dir', create=False)
 dirscan_speed = OptionNumber('misc', 'dirscan_speed', DEF_SCANRATE, 0, 3600)
 SIZE_LIMIT = OptionStr('misc', 'size_limit')
 password_file = OptionDir('misc', 'password_file', '', create=False)
