@@ -194,7 +194,9 @@ class NzbFile(TryList):
         self.valid = bool(article_db)
 
         if self.valid and self.nzf_id:
-            sabnzbd.save_data(article_db, self.nzf_id, nzo.workpath)
+            if not sabnzbd.save_data(article_db, self.nzf_id, nzo.workpath):
+                logging.info('Saving %s failed', latin1(os.path.join(nzo.workpath, self.nzf_id)))
+                raise IOError
 
     def finish_import(self):
         """ Load the article objects from disk """
@@ -320,6 +322,7 @@ class NzbParser(xml.sax.handler.ContentHandler):
         self.nzf_list = []
         self.groups = []
         self.filter = remove_samples
+        self.now = time.time()
 
     def startDocument(self):
         pass
@@ -356,8 +359,8 @@ class NzbParser(xml.sax.handler.ContentHandler):
                 try:
                     self.file_date = int(attrs.get('date'))
                 except:
-                    # NZB has non-standard timestamp, assume 1
-                    self.file_date = 1
+                    # NZB has non-standard timestamp, assume now
+                    self.file_date = self.now
                 self.article_db = {}
                 self.file_bytes = 0
 
@@ -410,7 +413,11 @@ class NzbParser(xml.sax.handler.ContentHandler):
             if not self.article_db:
                 logging.warning(Ta('File %s is empty, skipping'), self.filename)
                 return
-            tm = datetime.datetime.fromtimestamp(self.file_date)
+            try:
+                tm = datetime.datetime.fromtimestamp(self.file_date)
+            except:
+                tm = datetime.datetime.fromtimestamp(self.now)
+                self.file_date = self.now
             nzf = NzbFile(tm, self.filename, self.article_db, self.file_bytes, self.nzo)
             if nzf.valid and nzf.nzf_id:
                 logging.info('File %s added to queue', self.filename)
@@ -489,7 +496,8 @@ NzbObjectMapper = (
     ('extra6',                       'encrypted'),     # Encrypted RAR file encountered
     ('duplicate',                    'duplicate'),     # Was detected as a duplicate
     ('oversized',                    'oversized'),     # Was detected as oversized
-    ('create_group_folder',          'create_group_folder')
+    ('create_group_folder',          'create_group_folder'),
+    ('aborted',                      'aborted')        # Download aborted due to admin errors
 )
 
 class NzbObject(TryList):
@@ -574,6 +582,7 @@ class NzbObject(TryList):
         self.parsed = False
         self.duplicate = False
         self.oversized = False
+        self.aborted = False
 
         # Store one line responses for filejoin/par2/unrar/unzip here for history display
         self.action_line = ''
@@ -657,6 +666,10 @@ class NzbObject(TryList):
                 logging.warning(Ta('Invalid NZB file %s, skipping (reason=%s, line=%s)'),
                               filename, err.getMessage(), err.getLineNumber())
                 raise ValueError
+            except IOError:
+                self.purge_data(keep_basic=reuse)
+                logging.warning(Ta('Cannot save NZB admin files for "%s"'), latin1(self.work_name))
+                raise ValueError
             except Exception, err:
                 self.purge_data(keep_basic=reuse)
                 logging.warning(Ta('Invalid NZB file %s, skipping (reason=%s, line=%s)'), filename, err, 0)
@@ -815,7 +828,7 @@ class NzbObject(TryList):
                         else:
                             if not file_done:
                                 nzf.reset_try_list()
-                                self.files.remove(nzf)
+                                if nzf in self.files: self.files.remove(nzf)
                                 self.extrapars[head].append(nzf)
                     ## No par2file in this set yet, set this as
                     ## initialparfile
@@ -1010,7 +1023,9 @@ class NzbObject(TryList):
                             if not nzf.import_finished:
                                 logging.error(Ta('Error importing %s'), nzf)
                                 nzf_remove_list.append(nzf)
-                                continue
+                                nzf.nzo.aborted = True
+                                sabnzbd.nzbqueue.NzbQueue.do.finish_nzo(nzf.nzo)
+                                return None
                         else:
                             continue
 
