@@ -123,7 +123,7 @@ class PostProcessor(Thread):
             self.history_queue.remove(nzo)
         except:
             nzo_id = getattr(nzo, 'nzo_id', 'unknown id')
-            logging.error(Ta('Failed to remove nzo from postproc queue (id)'), nzo_id)
+            logging.error(Ta('Failed to remove nzo from postproc queue (id)') + ' ' + nzo_id)
         self.save()
 
     def stop(self):
@@ -232,6 +232,9 @@ def process_job(nzo):
         all_ok = False
 
     try:
+        if nzo.aborted:
+            crash_msg = T('Download aborted due to admin errros')
+            raise IOError
 
         # Get the folder containing the download result
         workdir = nzo.downpath
@@ -423,7 +426,8 @@ def process_job(nzo):
                                     T('View script output')), unique=True)
 
         ## Cleanup again, including NZB files
-        cleanup_list(workdir_complete, False)
+        if all_ok:
+            cleanup_list(workdir_complete, False)
 
         ## Remove newzbin bookmark, if any
         if msgid and all_ok:
@@ -526,16 +530,22 @@ def parring(nzo, workdir):
 
         logging.info('Par2 check finished on %s', filename)
 
-    else:
+    if (par_error and not re_add) or not repair_sets:
         # See if alternative SFV check is possible
-        sfv = None
         if cfg.sfv_check():
-            for sfv in globber(workdir, '*.sfv'):
-                par_error = par_error or not sfv_check(sfv)
-            if par_error:
-                nzo.set_unpack_info('Repair', T('Some files failed to verify against "%s"') % unicoder(os.path.basename(sfv)))
-
-        if not sfv:
+            sfvs = globber(workdir, '*.sfv')
+        else:
+            sfvs = None
+        if sfvs:
+            par_error = False
+            nzo.set_unpack_info('Repair', T('Trying SFV verification'))
+            for sfv in sfvs:
+                if not sfv_check(sfv):
+                    nzo.set_unpack_info('Repair', T('Some files failed to verify against "%s"') % unicoder(os.path.basename(sfv)))
+                    par_error = True
+            if not par_error:
+                nzo.set_unpack_info('Repair', T('Verified successfully using SFV files'))
+        elif not repair_sets:
             logging.info("No par2 sets for %s", filename)
             nzo.set_unpack_info('Repair', T('[%s] No par2 sets') % unicoder(filename))
 
